@@ -24,7 +24,7 @@ Revision History
 // Basic int types of various widths
 //
 
-#if !defined(__STDC_VERSION__) || (__STDC_VERSION__ < 199901L )
+#if !defined(__STDC_VERSION__) || (__STDC_VERSION__ < 199901L ) && !defined(__cplusplus)
 
     // No ANSI C 1999/2000 stdint.h integer width declarations 
 
@@ -62,6 +62,8 @@ Revision History
         typedef unsigned char       uint8_t;
         typedef char                int8_t;
     #endif
+    typedef uint64_t            uintptr_t;
+    typedef int64_t             intptr_t;
 #elif defined(__GNUC__)
     #include <stdint.h>
 #endif
@@ -69,24 +71,27 @@ Revision History
 //
 // Basic EFI types of various widths
 //
-#ifndef __WCHAR_TYPE__
-# define __WCHAR_TYPE__	short
-#endif
 
+#include <stddef.h>
+
+typedef wchar_t CHAR16;
+#define WCHAR CHAR16
 
 typedef uint64_t   UINT64;
 typedef int64_t    INT64;
+
 typedef uint32_t   UINT32;
 typedef int32_t    INT32;
+
 typedef uint16_t   UINT16;
 typedef int16_t    INT16;
-typedef uint8_t    UINT8;
-typedef int8_t     INT8;
-typedef __WCHAR_TYPE__ WCHAR;
 
+typedef uint8_t    UINT8;
+typedef char       CHAR8;
+typedef int8_t     INT8;
 
 #undef VOID
-#define VOID    void
+typedef void       VOID;
 
 
 typedef int64_t    INTN;
