@@ -32,11 +32,9 @@ typedef uint16_t                UINT16;
 typedef int16_t                 INT16;
 typedef uint8_t                 UINT8;
 typedef int8_t                  INT8;
+typedef char                    CHAR8;
 typedef wchar_t                 CHAR16;
 #define WCHAR                   CHAR16
-#ifndef BOOLEAN
-typedef uint8_t                 BOOLEAN;
-#endif
 #undef VOID
 typedef void                    VOID;
 typedef int64_t                 INTN;
